.. _seitzman_atlas:

Seitzman 2018 atlas
===================

Access
------
See :func:`nilearn.datasets.fetch_coords_seitzman_2018`.

Notes
-----
300 ROI coordinates in cortical, subcortical and cerebellar regions.

    Here, we apply a winner-take-all partitioning method
    to :term:`resting-state` :term:`fMRI` data
    and careful consideration of anatomy to generate novel functionally-constrained ROIs
    in the thalamus, basal ganglia, amygdala, hippocampus, and cerebellum.
    We validate these ROIs in three datasets via several anatomical and functional criteria,
    including known anatomical divisions and functions,
    as well as agreement with existing literature.
    Further, we demonstrate that combining these ROIs with established cortical ROIs recapitulates
    and extends previously described functional network organization.

    :footcite:t:`Seitzman2020`

Content
-------
    :"rois": Coordinates of 300 ROIs in :term:`MNI` space
    :"radius": Radius of each ROI in mm
    :"networks": Network names
    :"regions": Region names

References
----------

.. footbibliography::

For more information see:
https://greenelab.ucsd.edu/data_software

ROI coordinates downloaded from:
https://wustl.app.box.com/s/twpyb1pflj6vrlxgh3rohyqanxbdpelw

License
-------
unknown
